FallbackJudgment: compose a primary judgment backend with a fallback
one.
Structs
- Fallback
Judgment - A judgment backend that tries a primary backend first and falls back to a second backend when the primary fails in a way the fallback can fix.